.. _algorithms:

Algorithms
==========

This guide contains in-depth descriptions of the algorithms used in the TidyMS2 library. The purpose
of these guides is to focus on the theoretical background for each algorithm. For usage instructions,
refer to the :ref:`user-guide` or the :ref:`api`.

.. toctree::
   :maxdepth: 1

   algorithms/roi-extraction
   algorithms/peak-extraction
   algorithms/correspondence